/*
 * AVRGCC1.c
 *
 * Created: 15.02.2012 08:38:12
 *  Author: Senna Hoi
 */ 

#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdint.h>

//Funktion fr Timer Konfiguration
void timer0_init(void);
//Funktion fr Interrupt
void interrupt_init(void);
//Funktion fr Clock Konfiguration
void clock_init(void);
//Funktion fr PIO Konfiguration
void port_init(void);


#define MCK 32768000//32000000

#define FREQUNCY 160000 // kHz
#define TC_PRESCALER TC_CLKSEL_DIV1_gc

// ----------------------------------------------------------------------------
//* Variablen
// ----------------------------------------------------------------------------

// TimerCounter Frequenz fr Interrupt
int16_t i16_frequency = (MCK/(1*TC_PRESCALER*FREQUNCY))-1;


uint8_t ui8_signal_counter = 0;	// Zhlt die 16 Werte des Sinus durch

void clock_init(void){
//Oszillator auf 32Mhz stellen
OSC.CTRL = 0x02;
CLK.PSCTRL = 0x00;
// Warten bis der Oszillator bereit ist
while(!(OSC.STATUS & OSC_RC32MRDY_bm));
// I/O protection
CCP = CCP_IOREG_gc;
//32Mhz Clock aktivieren
CLK.CTRL = 0x01;

PORTCFG.CLKEVOUT = 0x01;
}

void interrupt_init(void){
//Globale Interruptfreigabe
sei();
//Interrupts (Highlevel,Mediumlevel und Lowlevel freigeben)
PMIC.CTRL |= (1<<PIN0) | (1<<PIN1)|(1<<PIN2);
}

void timer0_init(void){
	
	//PD0(OCA) als Ausgang definieren
	TCC0.CNT = 0x00;
	/*Timer-Top-Wert fhrt einen Interrupt durch*/
	TCC0.PER =  i16_frequency;
	/* Vorteiler */
	TCC0.CTRLA = TC_PRESCALER;
	/*Timer im Normalmodus*/
	TCC0.CTRLB = 0x00;
	/*Interrupt konfigurieren*/
	TCC0.INTCTRLA = 0x03;
}

void port_init(void){
	PORTC.DIR = (1<<PIN4)|(1<<PIN5)|(1<<PIN7);
	PORTA.DIR = 0x00;//0xFF;
	//PORTA.OUTCLR = 0xFF;
	PORTB.DIR = 0xFF;
	PORTE.DIR = 0xFF;
	PORTE.OUT = 0xFF;
}

ISR(TCC0_OVF_vect){
	PORTE.OUTSET = 0x01;
	
	// Zhlt von 0 bis 31
	ui8_signal_counter++;
	ui8_signal_counter &= 0x0F;

	PORTE.OUTCLR = 0x01;
}


int main(void){
	//Clock Konfiguration wird aufgerufen
	clock_init();
	//Interrupt Konfiguration
	interrupt_init();
	//Timer Konfiguration wird aufgerufen
	timer0_init();
	// Port Konfiguration wird aufgerufen
	port_init();

	for(;;)
	{
		//Toggelt mir einen Pin
		PORTE.OUTTGL = 0x08;
	}
}